uuid_plus library
UUID Plus library.
A fork of the original dart-uuid package with improvements. Simple, fast generation of RFC4122 and RFC9562 UUIDs.
Classes
- CryptoRNG
- Crypto-Strong RNG. All platforms, unknown speed, cryptographically strong (theoretically)
- GlobalOptions
- GlobalOptions stores the global options passed into the library on instantiation. GlobalOptions.rng is the random number generator class to use. Defaults to CryptoRNG() CryptoRNG
- InternalConstants
- LegacyRNG
- MathRNG
-
Math.Random()-based RNG. All platforms, fast, not cryptographically
strong. Optional
seedcan be passed on creation. - MathRNGDeprecated
- Math.Random()-based RNG. All platforms, fast, not cryptographically strong. Optional seed can be passed on creation.
- RNG
- Uuid
- uuid for Dart Author: Yulian Kuncheff Released under MIT License.
- UuidParsing
- UuidV1
- UuidV4
- UuidV5
- UuidV6
- UuidV7
- UuidV8
- UuidV8Generic
- UuidValidation
- UuidValue
- V1Options
-
V1Options stores the options passed into the v1 function.
clockSeq (Number between 0 - 0x3fff) RFC clock sequence.
Default: An internally maintained clockseq is used.
mSecs is the time in milliseconds since the unix epoch. Defualt: Now.
nSecs is the number of 100-nanosecond intervals since the last mSecs.
Ignored if
msecsis unspecified. Default: internal uuid counter is used, as per 4.2.1.2. node Node id as List of 6 bytes (per 4.1.6). Default: Randomnly generated ID. seedBytes is the random bytes to use to generate the node id and clock sequence. Primarily used for testing, or recreating a UUID - V1State
- V1State stores the state of the v1 function. nodeId is the node id currently being used clockSeq is the clock sequence currently being used mSecs is the time in milliseconds since the unix epoch nSecs is the number of 100-nanosecond intervals since the last mSecs initialized is a boolean to indicate whether or not the state has been initialized once already. Prevents re-initialization on subsequent calls to _init() from within the v1 function.
- V4Options
- V4Options stores the options passed into the v4 function. random is the random bytes to use to generate the UUID. Primarily used for testing, or recreating a UUID rng is the random number generator function to use. Defaults to CryptoRNG() CryptoRNG
- V4State
- V4State stores the random number generator state for the v4 function. random is a instantiation of the RNG state being used. initialized is a boolean to indicate whether or not the state has been initialized once already. Prevents re-initialization on subsequent calls to _init() from within the v4 function.
- V5Options
- V5Options stores the options passed into the v5 function. randomNamespace is a boolean to indicate whether or not to use a random namespace. Defaults to true. v4options is the options to pass into the v4 function to generate the random namespace.
- V6Options
-
V6Options stores the options passed into the v6 function.
clockSeq (Number between 0 - 0x3fff) RFC clock sequence.
Default: An internally maintained clockseq is used.
mSecs is the time in milliseconds since the unix epoch. Defualt: Now.
nSecs is the number of 100-nanosecond intervals since the last mSecs.
Ignored if
msecsis unspecified. Default: internal uuid counter is used, as per 4.2.1.2. node Node id as List of 6 bytes (per 4.1.6). Default: Randomnly generated ID. seedBytes is the random bytes to use to generate the node id and clock sequence. Primarily used for testing, or recreating a UUID - V6State
- V6State stores the state of the v1 function. nodeId is the node id currently being used clockSeq is the clock sequence currently being used mSecs is the time in milliseconds since the unix epoch nSecs is the number of 100-nanosecond intervals since the last mSecs initialized is a boolean to indicate whether or not the state has been initialized once already. Prevents re-initialization on subsequent calls to _init() from within the v6 function.
- V7Options
- V7Options stores the options passed into the v7 function. time is the time in milliseconds since the unix epoch randomBytes is the random bytes to use to generate the UUID. Primarily used for testing, or recreating a UUID
- V7State
- V7State stores the random number generator state for the v4 function. random is a instantiation of the RNG state being used. initialized is a boolean to indicate whether or not the state has been initialized once already. Prevents re-initialization on subsequent calls to _init() from within the v4 function.
- V8GenericOptions
- V8GenericOptions stores the options passed into the v8g function. data is the 122 bytes of custom data.
- V8Options
- V8Options stores the options passed into the v8 function. time is the time in milliseconds since the unix epoch randomBytes is the random bytes to use to generate the UUID. Primarily used for testing, or recreating a UUID
- V8State
- V8State stores the random number generator state for the v4 function. random is a instantiation of the RNG state being used. initialized is a boolean to indicate whether or not the state has been initialized once already. Prevents re-initialization on subsequent calls to _init() from within the v4 function.
Enums
- Namespace
- RFC4122 & RFC9562 provided namespaces for v3, v5, and v8 namespace based UUIDs
- ValidationMode
- The options for UUID Validation strictness